@@ -394,6 +394,51 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
         """
         raise NotImplementedError()
 
+    @property
+    @abstractmethod
+    def metadata(self):
+        """Metadata
+
+        Get the metadata.json file as a dictionary
+
+        :return: Dictionary built from metadata.json for the project
+        """
+        raise NotImplementedError()
+
+    @abstractmethod
+    def writeMetadata(self, metadata):
+        """Write Metadata
+
+        Write the metadata dictionary to metadata.json.
+        TODO: Perform validation of keys?
+
+        :param metadata: Dictionary for the metadata.json object
+        :return: None
+        """
+        raise NotImplementedError()
+
+    @abstractmethod
+    def getRevision(self) -> str:
+        """Get Revision
+
+        Get the (alembic) revision for the project
+
+        :return: String revision for the project that can be used with Alembic
+        """
+        raise NotImplementedError()
+
+    @abstractmethod
+    def setRevision(self, revision: str):
+        """Set Revision
+
+        Set the revision of the project. `revision` is an Alembic revision
+        string
+
+        :param revision: Alembic revision string
+        :return: None
+        """
+        raise NotImplementedError()
+
     @abstractmethod
     def validateItem(self, item):
         """Validate Item
